<?xml version="1.0" ?><!DOCTYPE TS><TS language="bn" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="120"/>
        <source>Deepin Movie</source>
        <translation>ডিপিন মুভি</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>ডিপিন মুভি একটি বর্ডার বিহীন সুন্দর ডিজাইনের এবং পরিপূর্ণ বৈশিষ্টযুক্ত ভিডিও প্লেয়ার। এটা দিয়ে বিভিন্ন ফরম্যাটের ভিডিও স্থানীয়ভাবে এবং স্ট্রিমিং করে চালানো যায়। </translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>ফোল্ডারটি অবৈধ</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open folder</source>
        <translation>ফোল্ডার খুলুন</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>আপনার কাছে এই ফোল্ডারটি পরিচালনা করার অনুমতি নেই</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>একই ধরণের ফাইলগুলো অটোমেটিক চলার জন্য যুক্ত করুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>বের হয়ে যাবার সময় চলার তালিকা মুছে ফেলুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>মাউস নেওয়ার সাথে সাথেই ভিডিওর প্রিভিউ দেখান। </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>প্রত্যেকটি ফাইল চলতে নতুন প্লেয়ার খুলুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>মিনিমাইজ করলে থেমে যান</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>সর্বশেষ চালানো অবস্থা মনে রাখুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>পথ </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>প্রাথমিক</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>চালু করুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation> স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>শর্টকাট</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>ফাইল </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>ফ্রেম/শব্দ </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>চালান </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>সাবটাইটেল</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>ফন্ট স্টাইল</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>পূর্বনির্ধারিত জিনিসে ফিরে যান</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>ফাইল খুলুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>পরবর্তীটি খুলুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>পূর্ববর্তীটি খুলুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>ছোট রূপ</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>নীরব</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>Next frame</source>
        <translation>পরবর্তী ফ্রেম</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Previous frame</source>
        <translation>পূর্বের ফ্রেম</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>Volume down</source>
        <translation>শব্দ কমান</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Volume up</source>
        <translation>শব্দ বাড়ান</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Speed up</source>
        <translation>গতি বাড়ান</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Speed down</source>
        <translation>গতি কমান</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Fullscreen</source>
        <translation>সম্পূর্ণ পর্দা</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Pause/Play</source>
        <translation>থামুন/চালান </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Playlist</source>
        <translation>চালানোর তালিকা</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Reset speed</source>
        <translation>গতি পুনরায় সেট করুন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Rewind</source>
        <translation>আবার গুটিয়ে নিন</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Forward</source>
        <translation>সামনে</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>Burst screenshot</source>
        <translation>একসাথে অনেকগুলো স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>Film screenshot</source>
        <translation>ফিল্ম স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>0.5s backward</source>
        <translation>0.5s পিছনে</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>0.5s forward</source>
        <translation>0.5s সামনে</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="45"/>
        <source>Font</source>
        <translation>ফন্ট</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="46"/>
        <source>Font Size</source>
        <translation>ফন্টের আকার</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>বাতিল</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>নিশ্চিত করুন</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>দয়াকরে URL প্রবেশ করান</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="269"/>
        <source>Settings</source>
        <translation>সেটিংস</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>সম্পূর্ণ পর্দা</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>সবসময় উপরে</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="284"/>
        <source>Film info</source>
        <translation>ফিল্মের তথ্য</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open file</source>
        <translation>ফাইল খুলুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open folder</source>
        <translation>ফোল্ডার খুলুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light theme</source>
        <translation>হালকা থিম</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>URL খুলুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>CD/DVD খুলুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>ছোট রূপ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>চালানোর ধরণ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>ধারাবাহিকভাবে চালান</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>অদলবদল করে চালান</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>একটিমাত্র চালান</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>একবার ঘুড়ুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>সম্পূর্ণ তালিকা বার বার ঘুড়ুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>ফ্রেম</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>পূর্বনির্ধারিত</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>ঘড়ির কাটার দিকে</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>ঘড়ির কাটার বিপরীত দিকে</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="144"/>
        <source>Next frame</source>
        <translation>পরের ফ্রেম</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="145"/>
        <source>Previous frame</source>
        <translation>পূর্বের ফ্রেম</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="152"/>
        <source>Sound</source>
        <translation>শব্দ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Channel</source>
        <translation>চ্যানেল</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="158"/>
        <source>Stereo</source>
        <translation>স্টেরিও</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="159"/>
        <source>Left channel</source>
        <translation>বামদিকের চ্যানেল</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="160"/>
        <source>Right channel</source>
        <translation>ডানদিকের চ্যানেল</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="166"/>
        <source>Track</source>
        <translation>রেকর্ড করা শব্দ</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="176"/>
        <source>Subtitle</source>
        <translation>সাবটাইটেল</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="177"/>
        <source>Load</source>
        <translation>লোড করুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Online Search</source>
        <translation>অনলাইনে খুজুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Select</source>
        <translation>নির্বাচন করুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Hide</source>
        <translation>লুকান</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="190"/>
        <source>Encodings</source>
        <translation>এনকোডিং</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="258"/>
        <source>Screenshot</source>
        <translation> স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="259"/>
        <source>Film Screenshot</source>
        <translation>ফিল্ম স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="260"/>
        <source>Burst Shooting</source>
        <translation>অনেকগুলি স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="267"/>
        <source>Playlist</source>
        <translation>চলার তালিকা</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="268"/>
        <source>Film Info</source>
        <translation>ফিল্মের তথ্য</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="282"/>
        <source>Clear playlist</source>
        <translation>চলার তালিকা মুছে ফেলুন</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="283"/>
        <source>Display in file manager</source>
        <translation>ফাইল ম্যানেজার দেখান</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>Duration: %1</source>
        <translation>সময়কাল: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>Resolution: %1</source>
        <translation>রেজূূলিউশন: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>Size: %1</source>
        <translation>আকার: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>Save</source>
        <translation>সংরক্ষণ করুন</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="720"/>
        <location filename="../common/mainwindow.cpp" line="1821"/>
        <source>Load successfully</source>
        <translation>সফলভাবে লোড হয়েছে</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="720"/>
        <location filename="../common/mainwindow.cpp" line="1821"/>
        <source>Load failed</source>
        <translation>লোড করতে বার্থ হয়েছে</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1424"/>
        <source>No device found</source>
        <translation>কোনো ডিভাইস পাওয়া যায়নি</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1442"/>
        <source>Parse Failed</source>
        <translation>শব্দবিশ্লেষণ করতে ব্যর্থ হয়েছে</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1449"/>
        <source>Open folder</source>
        <translation>ফোল্ডার খুলুন</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1464"/>
        <location filename="../common/mainwindow.cpp" line="1481"/>
        <location filename="../common/mainwindow.cpp" line="1816"/>
        <source>Open file</source>
        <translation>ফাইল খুলুন</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1466"/>
        <location filename="../common/mainwindow.cpp" line="1483"/>
        <source>All videos (%1)</source>
        <translation>সকল ভিডিওসমূহ(%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <source>Muted</source>
        <translation>নীরব করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1687"/>
        <location filename="../common/mainwindow.cpp" line="1699"/>
        <location filename="../common/mainwindow.cpp" line="1709"/>
        <location filename="../common/mainwindow.cpp" line="1716"/>
        <source>Volume: %1%</source>
        <translation>শব্দ: %1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1781"/>
        <location filename="../common/mainwindow.cpp" line="1789"/>
        <source>Subtitle %1: %2s</source>
        <translation>সাবটাইটেল %1: %2s</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1782"/>
        <location filename="../common/mainwindow.cpp" line="1790"/>
        <source>delayed</source>
        <translation>বিলম্ব করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1782"/>
        <location filename="../common/mainwindow.cpp" line="1790"/>
        <source>advanced</source>
        <translation>অ্যাডভান্সড</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1797"/>
        <location filename="../common/mainwindow.cpp" line="1804"/>
        <location filename="../common/mainwindow.cpp" line="1811"/>
        <source>Speed: %1x</source>
        <translation>গতি: %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1818"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <translation>সাবটাইটেল (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1880"/>
        <source>View</source>
        <translation>দেখুন</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1891"/>
        <source>Movie Screenshot</source>
        <translation>মুভি স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1892"/>
        <source>Saved to</source>
        <translation>এখানে সংরক্ষণ করুন</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1906"/>
        <location filename="../common/mainwindow.cpp" line="1989"/>
        <source>The screenshot is saved</source>
        <translation>স্ক্রিনশটটি সংরক্ষণ করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1906"/>
        <source>Failed to save the screenshot</source>
        <translation>স্ক্রিনশট সংরক্ষণ করতে বার্থ হয়েছে</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2076"/>
        <location filename="../common/mainwindow.cpp" line="2782"/>
        <source>Invalid file: %1</source>
        <translation>অবধৈ ফাইল: %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <location filename="../libdmr/playlist_model.h" line="67"/>
        <source>%1G</source>
        <translation>%1G</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="69"/>
        <source>%1M</source>
        <translation>%1M</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="71"/>
        <source>%1K</source>
        <translation>%1K</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="73"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>ফাইলের ধরণ:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>রেজোলিউশন:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>ফাইলের আকার:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>সময়কালঃ</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>ফাইলের পথ:</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1034"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1052"/>
        <source>[internal]</source>
        <translation>[অভ্যন্তরীণ]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>ফাইল নেই</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DMovie%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DMovie%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>চালু করুন</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>পূর্ববর্তী</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>পরবর্তী</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>সাবটাইটেল সমূহ</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>চলার তালিকা</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>সম্পূর্ণ পর্দা</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>চালান/থামুন</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>সম্পূর্ণ পর্দা থেকে বের হয়ে যান</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>থামুন</translation>
    </message>
</context>
</TS>